@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2011  Otfried Cheong
+    Copyright (C) 1993-2012  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@
 
 namespace ipe {
 
-  class Font;
+  struct Font;
 
   class PsPainter : public PdfPainter {
   public:
