@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2011  Otfried Cheong
+    Copyright (C) 1993-2012  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -81,8 +81,8 @@ bool Tool::key(int code, int modifiers, String text)
 
 // --------------------------------------------------------------------
 
-/*! \class ipeqt::PanTool
-  \ingroup qtcanvas
+/*! \class ipe::PanTool
+  \ingroup canvas
   \brief A tool for panning the canvas.
 */
 
